@@ -1,8 +1,8 @@
 #!/usr/bin/env python
+import json
 import os
 import re
 import subprocess
-import json
 
 import click
 from click.exceptions import ClickException
@@ -37,10 +37,11 @@ SEMVER_REGEX = (
 
 
 class ConfigNotFoundException(Exception):
-    pass
+    """Exception to raise when config not in config path"""
 
 
 def get_author_name(user):
+    """Returns the authors name"""
     name = user.get("name")
     email = user.get("email")
     username = user.get("username")
@@ -53,6 +54,7 @@ def get_author_name(user):
 
 
 def get_python_version():
+    """Returns active python version"""
     errors = []
 
     for python_binary_name in ["python3", "python"]:
@@ -65,12 +67,13 @@ def get_python_version():
                 stderr=subprocess.DEVNULL,
             )
             return _get_version_from_python_version_string(python_version_output)
-        except subprocess.CalledProcessError as e:
-            errors.append(e)
+        except subprocess.CalledProcessError as err:
+            errors.append(err)
 
     print(
-        "Error while trying to run `python --version`. Please make sure that python is installed and `python` "
-        "is available in path."
+        "Error while trying to run `python --version`. "
+        "Please make sure that python is installed "
+        "and `python` is available in path."
     )
     print(errors)
     raise Exception("Error while trying to get available python version")
@@ -87,7 +90,8 @@ def get_config(project_name, env):
     author_name = DEFAULT_AUTHOR_NAME
 
     if os.path.exists(get_config_path(env)):
-        config = json.loads(open(get_config_path(env), "r").read())
+        with open(get_config_path(env), "r", encoding="utf8") as file:
+            config = json.loads(file.read())
         author_name = get_author_name(config["user"])
 
     return {
@@ -108,7 +112,6 @@ def cli():
         arcl auth        Handle Archimedes authentication
         arcl version     Print the version number
     """
-    pass
 
 
 @cli.command(hidden=True)
@@ -124,6 +127,7 @@ def cli():
     help="Environment to setup",
 )
 def auth(action, organization, env):
+    """Method for handling auth operations"""
     accepted_env = get_accepted_env()
     if env not in accepted_env:
         raise ClickException(f"env should be one of {accepted_env}")
@@ -151,12 +155,14 @@ def auth(action, organization, env):
     "--template-version",
     "-t",
     "template_version",
-    help=f"Version of the template to use. It can be a branch, name or tag of the git repo of "
+    help=f"Version of the template to use. "
+    f"It can be a branch, name or "
+    f"tag of the git repo of "
     f"{COOKIECUTTER_TEMPLATE_GIT_URL}",
     default=None,
 )
 def new(name, template_version):
-    """"""
+    """Creates a new arcl project"""
     try:
         project_dir = cookiecutter(
             COOKIECUTTER_TEMPLATE_GIT_URL,
@@ -164,18 +170,18 @@ def new(name, template_version):
             extra_context=get_config(name, "prod"),
             no_input=True,
         )
-    except ConfigNotFoundException as e:
-        click.echo(e)
+    except ConfigNotFoundException as err:
+        click.echo(err)
         return
 
-    click.echo(f"\nYour new project has been created!")
+    click.echo("\nYour new project has been created!")
     click.echo("")
     click.echo(f'$ cd "{project_dir}"')
-    click.echo(f"$ python -m pip install wheel pip --upgrade")
-    click.echo(f"$ poetry update --lock")
-    click.echo(f"$ poetry install")
+    click.echo("$ python -m pip install wheel pip --upgrade")
+    click.echo("$ poetry update --lock")
+    click.echo("$ poetry install")
     click.echo("")
-    click.echo(f"to get started.")
+    click.echo("to get started.")
     click.echo("")
 
 
